@@ -3,6 +3,7 @@ import csv
 import tempfile
 import subprocess
 import logging
+import warnings
 import typing
 import scrapelib
 import lxml.html  # type: ignore
@@ -25,6 +26,25 @@ def _to_scout_result(result: typing.Any) -> typing.Dict[str, typing.Any]:
     }
 
 
+class SkipItem(Exception):
+    """
+    To be raised within `ListPage` subclass to skip processing of the current item
+    & continue with the next item.
+
+    Example:
+    ``` python
+    class SomeListPage(HtmlListPage):
+        def process_item(self, item):
+            if item.name == "Vacant":
+                raise SkipItem("vacant")
+            # do normal processing here
+    ```
+    """
+
+    def __init__(self, msg: str):
+        super().__init__(msg)
+
+
 class MissingSourceError(Exception):
     def __init__(self, msg: str):
         super().__init__(msg)
@@ -357,17 +377,12 @@ class ListPage(Page):
     **Methods**
     """
 
-    class SkipItem(Exception):
-        def __init__(self, msg: str):
-            super().__init__(msg)
-
-    def skip(self, msg: str = "") -> None:
-        """
-        Can be called from within `process_item` to skip a given item.
-
-        Typically used if there is some known bad data.
-        """
-        raise self.SkipItem(msg)
+    def skip(self, msg: str = "") -> None:  # pragma: no cover
+        warnings.warn(
+            "self.skip is deprecated and will be removed in 0.9, raise SkipItem instead",
+            DeprecationWarning,
+        )
+        raise SkipItem(msg)
 
     def _process_or_skip_loop(
         self, iterable: typing.Iterable
@@ -375,8 +390,8 @@ class ListPage(Page):
         for item in iterable:
             try:
                 item = self.process_item(item)
-            except self.SkipItem as e:
-                self.logger.debug(f"SkipItem: {e}")
+            except SkipItem as e:
+                self.logger.info(f"SkipItem: {e}")
                 continue
             yield item
 
@@ -385,6 +400,11 @@ class ListPage(Page):
         To be overridden.
 
         Called once per subitem on page, as defined by the particular subclass being used.
+
+        Should return data extracted from the `item`.
+
+        If [`SkipItem`](#SkipItem) is raised, `process_item` will continue to be called with
+        the next item in the stream.
         """
         return item
 
@@ -402,7 +422,7 @@ class CsvListPage(ListPage):
         yield from self._process_or_skip_loop(self.reader)
 
 
-class ExcelListPage(ListPage):
+class ExcelListPage(ListPage):  # pragma: no cover
     """
     Processes each row in an Excel file as an item with `process_item`.
     """
